| Title: | The Official SolveBio API Client |
|---|---|
| Description: | R language bindings for SolveBio's API (DEPRECATED: This package will no longer be maintained after March 31, 2026). SolveBio is a biomedical knowledge hub that enables life science organizations to collect and harmonize the complex, disparate "multi-omic" data essential for today's R&D and BI needs. |
| Authors: | Tobi Guennel [aut, cre] |
| Maintainer: | Tobi Guennel <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 2.15.1 |
| Built: | 2026-05-13 07:38:47 UTC |
| Source: | https://github.com/solvebio/solvebio-r |
Annotate a data table/frame with additional fields.
Annotator.annotate( records, fields, include_errors = FALSE, raw = FALSE, env = solvebio:::.solveEnv )Annotator.annotate( records, fields, include_errors = FALSE, raw = FALSE, env = solvebio:::.solveEnv )
records |
The data table or data frame to annotate. |
fields |
The fields to add. |
include_errors |
Set to TRUE to include errors in the output (default: FALSE). |
raw |
Set to TRUE to return the raw response (default: FALSE). |
env |
(optional) Custom client environment. |
## Not run: Annotator.annotate(records=tbl, fields=fields) ## End(Not run)## Not run: Annotator.annotate(records=tbl, fields=fields) ## End(Not run)
Retrieves the metadata about all application on SolveBio available to the current user.
Application.all(env = solvebio:::.solveEnv, ...)Application.all(env = solvebio:::.solveEnv, ...)
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters. |
## Not run: Application.all() ## End(Not run)## Not run: Application.all() ## End(Not run)
Create a new SolveBio application.
Application.create(name, redirect_uris, env = solvebio:::.solveEnv, ...)Application.create(name, redirect_uris, env = solvebio:::.solveEnv, ...)
name |
The name of the application. |
redirect_uris |
A list of space-separated OAuth2 redirect URIs. |
env |
(optional) Custom client environment. |
... |
(optional) Additional application attributes. |
## Not run: Application.create( name="My new application", redirect_uris="http://localhost:3838/" ) ## End(Not run)## Not run: Application.create( name="My new application", redirect_uris="http://localhost:3838/" ) ## End(Not run)
Delete a specific application from SolveBio.
Application.delete(client_id, env = solvebio:::.solveEnv)Application.delete(client_id, env = solvebio:::.solveEnv)
client_id |
The client ID for the application. |
env |
(optional) Custom client environment. |
## Not run: Application.delete("abcd1234") ## End(Not run)## Not run: Application.delete("abcd1234") ## End(Not run)
Retrieves the metadata about a specific application SolveBio.
Application.retrieve(client_id, env = solvebio:::.solveEnv)Application.retrieve(client_id, env = solvebio:::.solveEnv)
client_id |
The client ID for the application. |
env |
(optional) Custom client environment. |
## Not run: Application.retrieve("abcd1234") ## End(Not run)## Not run: Application.retrieve("abcd1234") ## End(Not run)
Updates the attributes of an existing application.
Application.update(client_id, env = solvebio:::.solveEnv, ...)Application.update(client_id, env = solvebio:::.solveEnv, ...)
client_id |
The client ID for the application. |
env |
(optional) Custom client environment. |
... |
Application attributes to change. |
## Not run: Application.update( "abcd1234", name="New app name" ) ## End(Not run)## Not run: Application.update( "abcd1234", name="New app name" ) ## End(Not run)
Retrieves the metadata about all beacons on SolveBio accessible to the current user.
Beacon.all(env = solvebio:::.solveEnv, ...)Beacon.all(env = solvebio:::.solveEnv, ...)
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters. |
## Not run: Beacon.all() ## End(Not run)## Not run: Beacon.all() ## End(Not run)
Add a new beacon to an existing beacon set. The beacon set must already exist in order to add beacons.
Beacon.create( beacon_set_id, vault_object_id, title, env = solvebio:::.solveEnv, ... )Beacon.create( beacon_set_id, vault_object_id, title, env = solvebio:::.solveEnv, ... )
beacon_set_id |
The ID of the parent beacon set. |
vault_object_id |
The ID of the vault object (i.e. dataset) queried by the beacon. |
title |
The title displayed for the beacon. |
env |
(optional) Custom client environment. |
... |
(optional) Additional beacon attributes (such as description and params). |
## Not run: Beacon.create( beacon_set_id="1234", vault_object_id="1234567890", title="My new beacon" ) ## End(Not run)## Not run: Beacon.create( beacon_set_id="1234", vault_object_id="1234567890", title="My new beacon" ) ## End(Not run)
Delete a specific beacon from SolveBio.
Beacon.delete(id, env = solvebio:::.solveEnv)Beacon.delete(id, env = solvebio:::.solveEnv)
id |
The ID of the beacon. |
env |
(optional) Custom client environment. |
## Not run: Beacon.delete("1234567890") ## End(Not run)## Not run: Beacon.delete("1234567890") ## End(Not run)
Query an individual beacon.
Beacon.query(id, query, entity_type, env = solvebio:::.solveEnv, ...)Beacon.query(id, query, entity_type, env = solvebio:::.solveEnv, ...)
id |
The ID of the beacon. |
query |
The entity ID or query string. |
entity_type |
(optional) A valid SolveBio entity type. |
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters. |
## Not run: Beacon.query( id="1234", query="BRCA2", entity_type="gene" ) ## End(Not run)## Not run: Beacon.query( id="1234", query="BRCA2", entity_type="gene" ) ## End(Not run)
Retrieves the metadata about a specific beacon on SolveBio.
Beacon.retrieve(id, env = solvebio:::.solveEnv)Beacon.retrieve(id, env = solvebio:::.solveEnv)
id |
The ID of the beacon. |
env |
(optional) Custom client environment. |
## Not run: Beacon.retrieve("1234") ## End(Not run)## Not run: Beacon.retrieve("1234") ## End(Not run)
Updates the attributes of an existing beacon.
Beacon.update(id, env = solvebio:::.solveEnv, ...)Beacon.update(id, env = solvebio:::.solveEnv, ...)
id |
The ID of the beacon to update. |
env |
(optional) Custom client environment. |
... |
Beacon attributes to change. |
## Not run: Beacon.update( id="1234", title="New Beacon Title" ) ## End(Not run)## Not run: Beacon.update( id="1234", title="New Beacon Title" ) ## End(Not run)
Retrieves the metadata about all beacon sets on SolveBio accessible to the current user.
BeaconSet.all(env = solvebio:::.solveEnv, ...)BeaconSet.all(env = solvebio:::.solveEnv, ...)
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters. |
## Not run: BeaconSet.all() ## End(Not run)## Not run: BeaconSet.all() ## End(Not run)
Create a new beacon set.
BeaconSet.create( title, description, is_shared = FALSE, env = solvebio:::.solveEnv, ... )BeaconSet.create( title, description, is_shared = FALSE, env = solvebio:::.solveEnv, ... )
title |
The title displayed for the beacon set. |
description |
(optional) An optional description for the new beacon set. |
is_shared |
If TRUE, everyone else in your account will be able to see and query the beacon set, but will not be able to edit it. (Default: FALSE) |
env |
(optional) Custom client environment. |
... |
(optional) Additional beacon set attributes. |
## Not run: BeaconSet.create( title="My new beacon set", ) ## End(Not run)## Not run: BeaconSet.create( title="My new beacon set", ) ## End(Not run)
Delete a specific beacon set (including all its beacons) from SolveBio.
BeaconSet.delete(id, env = solvebio:::.solveEnv)BeaconSet.delete(id, env = solvebio:::.solveEnv)
id |
The ID of the beacon set. |
env |
(optional) Custom client environment. |
## Not run: BeaconSet.delete("1234") ## End(Not run)## Not run: BeaconSet.delete("1234") ## End(Not run)
Query a beacon set (i.e. all the beacons within a beacon set).
BeaconSet.query(id, query, entity_type, env = solvebio:::.solveEnv, ...)BeaconSet.query(id, query, entity_type, env = solvebio:::.solveEnv, ...)
id |
The ID of the beacon set. |
query |
The entity ID or query string. |
entity_type |
(optional) A valid SolveBio entity type. |
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters. |
## Not run: BeaconSet.query( id="1234", query="BRCA2", entity_type="gene" ) ## End(Not run)## Not run: BeaconSet.query( id="1234", query="BRCA2", entity_type="gene" ) ## End(Not run)
Retrieves the metadata about a specific beacon set on SolveBio.
BeaconSet.retrieve(id, env = solvebio:::.solveEnv)BeaconSet.retrieve(id, env = solvebio:::.solveEnv)
id |
The ID of the beacon set. |
env |
(optional) Custom client environment. |
## Not run: BeaconSet.retrieve("1234") ## End(Not run)## Not run: BeaconSet.retrieve("1234") ## End(Not run)
Updates the attributes of an existing beacon set.
BeaconSet.update(id, env = solvebio:::.solveEnv, ...)BeaconSet.update(id, env = solvebio:::.solveEnv, ...)
id |
The ID of the beacon set to update. |
env |
(optional) Custom client environment. |
... |
Beacon set attributes to change. |
## Not run: BeaconSet.update( id="1234", title="New Beacon Set Title" ) ## End(Not run)## Not run: BeaconSet.update( id="1234", title="New Beacon Set Title" ) ## End(Not run)
Create a new SolveBio environment.
createEnv(token, token_type = "Token", host = .solveEnv$host)createEnv(token, token_type = "Token", host = .solveEnv$host)
token |
A SolveBio API key or OAuth2 token |
token_type |
SolveBio token type (default: Token) |
host |
(optional) The SolveBio API host (default: https://api.solvebio.com) |
## Not run: env <- createEnv("MyAPIkey") User.retrieve(env = myEnv) ## End(Not run)## Not run: env <- createEnv("MyAPIkey") User.retrieve(env = myEnv) ## End(Not run)
A helper function to get or follow the current activity on a dataset.
Dataset.activity(id, follow = TRUE, env = solvebio:::.solveEnv)Dataset.activity(id, follow = TRUE, env = solvebio:::.solveEnv)
id |
String The ID of a SolveBio dataset |
follow |
Follow active tasks until they complete. |
env |
(optional) Custom client environment. |
## Not run: Dataset.activity("1234567890") ## End(Not run)## Not run: Dataset.activity("1234567890") ## End(Not run)
Retrieves the metadata about datasets on SolveBio.
Dataset.all(env = solvebio:::.solveEnv, ...)Dataset.all(env = solvebio:::.solveEnv, ...)
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters (e.g. page). |
## Not run: Dataset.all() ## End(Not run)## Not run: Dataset.all() ## End(Not run)
Returns the total number of records for a given SolveBio dataset.
Dataset.count(id, env = solvebio:::.solveEnv, ...)Dataset.count(id, env = solvebio:::.solveEnv, ...)
id |
The ID of a SolveBio dataset, or a Dataset object. |
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters (e.g. filters, limit, offset). |
## Not run: dataset <- Dataset.get_by_full_path("solvebio:public:/ClinVar/3.7.4-2017-01-30/Variants-GRCh37") Dataset.count(dataset) Dataset.count(dataset, filters='[["gene_symbol", "BRCA2"]]') ## End(Not run)## Not run: dataset <- Dataset.get_by_full_path("solvebio:public:/ClinVar/3.7.4-2017-01-30/Variants-GRCh37") Dataset.count(dataset) Dataset.count(dataset, filters='[["gene_symbol", "BRCA2"]]') ## End(Not run)
Create an empty SolveBio dataset.
Dataset.create( vault_id, vault_parent_object_id, name, env = solvebio:::.solveEnv, ... )Dataset.create( vault_id, vault_parent_object_id, name, env = solvebio:::.solveEnv, ... )
vault_id |
The ID of the vault. |
vault_parent_object_id |
The parent object (folder) ID in the vault. |
name |
The name of the dataset in the parent folder. |
env |
(optional) Custom client environment. |
... |
(optional) Additional dataset attributes. |
## Not run: Dataset.create(vault_id=vault$id, vault_parent_object_id=NULL, name="My Dataset") ## End(Not run)## Not run: Dataset.create(vault_id=vault$id, vault_parent_object_id=NULL, name="My Dataset") ## End(Not run)
Returns one page of documents from a SolveBio dataset and processes the response.
Dataset.data(id, filters, env = solvebio:::.solveEnv, ...)Dataset.data(id, filters, env = solvebio:::.solveEnv, ...)
id |
The ID of a SolveBio dataset, or a Dataset object. |
filters |
(optional) Query filters. |
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters (e.g. limit, offset). |
## Not run: Dataset.data("1234567890") ## End(Not run)## Not run: Dataset.data("1234567890") ## End(Not run)
Delete a specific dataset from SolveBio.
Dataset.delete(id, env = solvebio:::.solveEnv)Dataset.delete(id, env = solvebio:::.solveEnv)
id |
String The ID of a SolveBio dataset |
env |
(optional) Custom client environment. |
## Not run: Dataset.delete("1234567890") ## End(Not run)## Not run: Dataset.delete("1234567890") ## End(Not run)
Disables Global Beacon for the dataset.
Dataset.disable_global_beacon(id, env = solvebio:::.solveEnv)Dataset.disable_global_beacon(id, env = solvebio:::.solveEnv)
id |
The ID of a SolveBio dataset. |
env |
(optional) Custom client environment. |
## Not run: Dataset.disable_global_beacon("1234567890") ## End(Not run)## Not run: Dataset.disable_global_beacon("1234567890") ## End(Not run)
Enables Global Beacon for the the dataset.
Dataset.enable_global_beacon(id, env = solvebio:::.solveEnv)Dataset.enable_global_beacon(id, env = solvebio:::.solveEnv)
id |
The ID of a SolveBio dataset. |
env |
(optional) Custom client environment. |
## Not run: Dataset.enable_global_beacon("1234567890") ## End(Not run)## Not run: Dataset.enable_global_beacon("1234567890") ## End(Not run)
Retrieves aggregated statistics or term counts for one or more fields in a SolveBio dataset. Returns a list of data frames, one for each requested facet.
Dataset.facets(id, facets, env = solvebio:::.solveEnv, ...)Dataset.facets(id, facets, env = solvebio:::.solveEnv, ...)
id |
The ID of a SolveBio dataset, or a Dataset object. |
facets |
A list of one or more field facets. |
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters (e.g. filters, limit, offset). |
## Not run: Dataset.facets("1234567890", list("clinical_significance", "gene_symbol")) ## End(Not run)## Not run: Dataset.facets("1234567890", list("clinical_significance", "gene_symbol")) ## End(Not run)
Retrieves the list of fields and field metadata for a dataset.
Dataset.fields(id, env = solvebio:::.solveEnv, ...)Dataset.fields(id, env = solvebio:::.solveEnv, ...)
id |
The ID of a SolveBio dataset, or a Dataset object. |
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters (e.g. limit, offset). |
## Not run: Dataset.fields("1234567890") ## End(Not run)## Not run: Dataset.fields("1234567890") ## End(Not run)
A helper function to get a dataset by its full path.
Dataset.get_by_full_path(full_path, env = solvebio:::.solveEnv)Dataset.get_by_full_path(full_path, env = solvebio:::.solveEnv)
full_path |
A valid full path to a dataset. |
env |
(optional) Custom client environment. |
## Not run: Dataset.get_by_full_path("solvebio:public:/ClinVar/3.7.4-2017-01-30/Variants-GRCh37") ## End(Not run)## Not run: Dataset.get_by_full_path("solvebio:public:/ClinVar/3.7.4-2017-01-30/Variants-GRCh37") ## End(Not run)
Retrieves the global beacon status for the dataset.
Dataset.get_global_beacon_status( id, raise_on_disabled = FALSE, env = solvebio:::.solveEnv )Dataset.get_global_beacon_status( id, raise_on_disabled = FALSE, env = solvebio:::.solveEnv )
id |
The ID of a SolveBio dataset. |
raise_on_disabled |
Whether to raise an exception if Global Beacon is disabled or to return NULL. |
env |
(optional) Custom client environment. |
## Not run: Dataset.get_global_beacon_status("1234567890") ## End(Not run)## Not run: Dataset.get_global_beacon_status("1234567890") ## End(Not run)
A helper function to get or create a dataset by its full path.
Dataset.get_or_create_by_full_path(full_path, env = solvebio:::.solveEnv, ...)Dataset.get_or_create_by_full_path(full_path, env = solvebio:::.solveEnv, ...)
full_path |
A valid full path to a dataset. |
env |
(optional) Custom client environment. |
... |
Additional dataset creation parameters. |
## Not run: Dataset.get_or_create_by_full_path("MyVault:/folder/sub-folder/dataset") ## End(Not run)## Not run: Dataset.get_or_create_by_full_path("MyVault:/folder/sub-folder/dataset") ## End(Not run)
Queries a SolveBio dataset and returns an R data frame containing all records. Returns a single page of results otherwise (default).
Dataset.query( id, paginate = FALSE, use_field_titles = TRUE, env = solvebio:::.solveEnv, ... )Dataset.query( id, paginate = FALSE, use_field_titles = TRUE, env = solvebio:::.solveEnv, ... )
id |
The ID of a SolveBio dataset, or a Dataset object. |
paginate |
When set to TRUE, retrieves all records (memory permitting). |
use_field_titles |
(optional) Use field title instead of field name for query. |
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters (e.g. filters, limit, offset). |
## Not run: Dataset.query("12345678790", paginate=TRUE) ## End(Not run)## Not run: Dataset.query("12345678790", paginate=TRUE) ## End(Not run)
Retrieves the metadata about a specific dataset from SolveBio.
Dataset.retrieve(id, env = solvebio:::.solveEnv)Dataset.retrieve(id, env = solvebio:::.solveEnv)
id |
String The ID of a SolveBio dataset |
env |
(optional) Custom client environment. |
## Not run: Dataset.retrieve("1234567890") ## End(Not run)## Not run: Dataset.retrieve("1234567890") ## End(Not run)
Retrieves the template for a dataset.
Dataset.template(id, env = solvebio:::.solveEnv)Dataset.template(id, env = solvebio:::.solveEnv)
id |
String The ID of a SolveBio dataset |
env |
(optional) Custom client environment. |
## Not run: Dataset.template("1234567890") ## End(Not run)## Not run: Dataset.template("1234567890") ## End(Not run)
Updates the attributes of an existing dataset.
Dataset.update(id, env = solvebio:::.solveEnv, ...)Dataset.update(id, env = solvebio:::.solveEnv, ...)
id |
The ID of the dataset to update. |
env |
(optional) Custom client environment. |
... |
Dataset attributes to change. |
## Not run: Dataset.update( id="1234", name="New Dataset Name", ) ## End(Not run)## Not run: Dataset.update( id="1234", name="New Dataset Name", ) ## End(Not run)
Retrieves the metadata about all dataset commits on SolveBio.
DatasetCommit.all(env = solvebio:::.solveEnv, ...)DatasetCommit.all(env = solvebio:::.solveEnv, ...)
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters (e.g. page). |
## Not run: DatasetCommit.all() ## End(Not run)## Not run: DatasetCommit.all() ## End(Not run)
Deletes a specific dataset commit on SolveBio.
DatasetCommit.delete(id, env = solvebio:::.solveEnv)DatasetCommit.delete(id, env = solvebio:::.solveEnv)
id |
String The ID or full name of a SolveBio dataset commit. |
env |
(optional) Custom client environment. |
## Not run: DatasetCommit.delete(<ID>) ## End(Not run)## Not run: DatasetCommit.delete(<ID>) ## End(Not run)
Retrieves the metadata about a specific dataset commit on SolveBio.
DatasetCommit.retrieve(id, env = solvebio:::.solveEnv)DatasetCommit.retrieve(id, env = solvebio:::.solveEnv)
id |
String The ID of a SolveBio dataset commit. |
env |
(optional) Custom client environment. |
## Not run: DatasetCommit.retrieve(<ID>) ## End(Not run)## Not run: DatasetCommit.retrieve(<ID>) ## End(Not run)
Retrieves the metadata about all dataset exports on SolveBio.
DatasetExport.all(env = solvebio:::.solveEnv, ...)DatasetExport.all(env = solvebio:::.solveEnv, ...)
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters (e.g. page). |
## Not run: DatasetExport.all() ## End(Not run)## Not run: DatasetExport.all() ## End(Not run)
Create a new dataset export.
DatasetExport.create( dataset_id, format = "json", params = list(), follow = FALSE, env = solvebio:::.solveEnv, ... )DatasetExport.create( dataset_id, format = "json", params = list(), follow = FALSE, env = solvebio:::.solveEnv, ... )
dataset_id |
The target dataset ID. |
format |
(optional) The export format (default: json). |
params |
(optional) Query parameters for the export. |
follow |
(default: FALSE) Follow the export task until it completes. |
env |
(optional) Custom client environment. |
... |
(optional) Additional dataset export parameters. |
## Not run: DatasetExport.create(dataset_id=<ID>, format='json', params=list(fields=c("field_1"), limit=100)) ## End(Not run)## Not run: DatasetExport.create(dataset_id=<ID>, format='json', params=list(fields=c("field_1"), limit=100)) ## End(Not run)
Deletes a specific dataset export on SolveBio.
DatasetExport.delete(id, env = solvebio:::.solveEnv)DatasetExport.delete(id, env = solvebio:::.solveEnv)
id |
String The ID of a SolveBio dataset export. |
env |
(optional) Custom client environment. |
## Not run: DatasetExport.delete(<ID>) ## End(Not run)## Not run: DatasetExport.delete(<ID>) ## End(Not run)
Helper method to get the download URL for a dataset export.
DatasetExport.get_download_url(id, env = solvebio:::.solveEnv)DatasetExport.get_download_url(id, env = solvebio:::.solveEnv)
id |
The ID of the dataset export. |
env |
(optional) Custom client environment. |
## Not run: DatasetExport.get_download_url("1234567890") ## End(Not run)## Not run: DatasetExport.get_download_url("1234567890") ## End(Not run)
Retrieves the metadata about a specific dataset export on SolveBio.
DatasetExport.retrieve(id, env = solvebio:::.solveEnv)DatasetExport.retrieve(id, env = solvebio:::.solveEnv)
id |
String The ID of a SolveBio dataset export. |
env |
(optional) Custom client environment. |
## Not run: DatasetExport.retrieve(<ID>) ## End(Not run)## Not run: DatasetExport.retrieve(<ID>) ## End(Not run)
Retrieves the metadata about all dataset fields on SolveBio.
DatasetField.all(env = solvebio:::.solveEnv, ...)DatasetField.all(env = solvebio:::.solveEnv, ...)
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters (e.g. page). |
## Not run: DatasetField.all() ## End(Not run)## Not run: DatasetField.all() ## End(Not run)
Create a new dataset field.
DatasetField.create( dataset_id, name, data_type = "auto", env = solvebio:::.solveEnv, ... )DatasetField.create( dataset_id, name, data_type = "auto", env = solvebio:::.solveEnv, ... )
dataset_id |
The dataset ID. |
name |
The name of the dataset field. |
data_type |
(optional) The data type for the field (default: auto). |
env |
(optional) Custom client environment. |
... |
(optional) Additional dataset import attributes. |
## Not run: DatasetField.create(dataset_id=<ID>, name="my_field", title="My Field", data_type="string") ## End(Not run)## Not run: DatasetField.create(dataset_id=<ID>, name="my_field", title="My Field", data_type="string") ## End(Not run)
Returns the facets for a given dataset field.
DatasetField.facets(id, env = solvebio:::.solveEnv, ...)DatasetField.facets(id, env = solvebio:::.solveEnv, ...)
id |
String The ID of a dataset field. |
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters. |
## Not run: DatasetField.facets(691) ## End(Not run)## Not run: DatasetField.facets(691) ## End(Not run)
Retrieves the metadata about a specific dataset field.
DatasetField.retrieve(id, env = solvebio:::.solveEnv)DatasetField.retrieve(id, env = solvebio:::.solveEnv)
id |
String The ID of a dataset field. |
env |
(optional) Custom client environment. |
## Not run: DatasetField.retrieve(691) ## End(Not run)## Not run: DatasetField.retrieve(691) ## End(Not run)
Updates the attributes of an existing dataset field. NOTE: The data_type of a field cannot be changed.
DatasetField.update(id, env = solvebio:::.solveEnv, ...)DatasetField.update(id, env = solvebio:::.solveEnv, ...)
id |
The ID of the dataset field to update. |
env |
(optional) Custom client environment. |
... |
Dataset field attributes to change. |
## Not run: DatasetField.update( id="1234", title="New Field Title" ) ## End(Not run)## Not run: DatasetField.update( id="1234", title="New Field Title" ) ## End(Not run)
Retrieves the metadata about all dataset imports on SolveBio.
DatasetImport.all(env = solvebio:::.solveEnv, ...)DatasetImport.all(env = solvebio:::.solveEnv, ...)
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters (e.g. page). |
## Not run: DatasetImport.all() ## End(Not run)## Not run: DatasetImport.all() ## End(Not run)
Create a new dataset import. Either an object_id, manifest, or data_records is required.
DatasetImport.create( dataset_id, commit_mode = "append", env = solvebio:::.solveEnv, ... )DatasetImport.create( dataset_id, commit_mode = "append", env = solvebio:::.solveEnv, ... )
dataset_id |
The target dataset ID. |
commit_mode |
(optional) The commit mode (default: append). |
env |
(optional) Custom client environment. |
... |
(optional) Additional dataset import attributes. |
## Not run: DatasetImport.create(dataset_id=<ID>, upload_id=<ID>) ## End(Not run)## Not run: DatasetImport.create(dataset_id=<ID>, upload_id=<ID>) ## End(Not run)
Deletes a specific dataset import on SolveBio.
DatasetImport.delete(id, env = solvebio:::.solveEnv)DatasetImport.delete(id, env = solvebio:::.solveEnv)
id |
String The ID of a SolveBio dataset import. |
env |
(optional) Custom client environment. |
## Not run: DatasetImport.delete(<ID>) ## End(Not run)## Not run: DatasetImport.delete(<ID>) ## End(Not run)
Retrieves the metadata about a specific dataset import on SolveBio.
DatasetImport.retrieve(id, env = solvebio:::.solveEnv)DatasetImport.retrieve(id, env = solvebio:::.solveEnv)
id |
String The ID of a SolveBio dataset import. |
env |
(optional) Custom client environment. |
## Not run: DatasetImport.retrieve(<ID>) ## End(Not run)## Not run: DatasetImport.retrieve(<ID>) ## End(Not run)
Retrieves the metadata about all dataset migrations on SolveBio.
DatasetMigration.all(env = solvebio:::.solveEnv, ...)DatasetMigration.all(env = solvebio:::.solveEnv, ...)
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters (e.g. page). |
## Not run: DatasetMigration.all() ## End(Not run)## Not run: DatasetMigration.all() ## End(Not run)
Create a new dataset migration.
DatasetMigration.create( source_id, target_id, commit_mode = "append", source_params = NULL, target_fields = NULL, include_errors = FALSE, env = solvebio:::.solveEnv, ... )DatasetMigration.create( source_id, target_id, commit_mode = "append", source_params = NULL, target_fields = NULL, include_errors = FALSE, env = solvebio:::.solveEnv, ... )
source_id |
The source dataset ID. |
target_id |
The target dataset ID. |
commit_mode |
(optional) The commit mode (default: append). |
source_params |
(optional) The query parameters used on the source dataset. |
target_fields |
(optional) A list of valid dataset fields to add or override in the target dataset. |
include_errors |
(optional) If TRUE, a new field (_errors) will be added to each record containing expression evaluation errors (default: FALSE). |
env |
(optional) Custom client environment. |
... |
(optional) Additional dataset migration attributes. |
## Not run: DatasetMigration.create(dataset_id=<ID>, upload_id=<ID>) ## End(Not run)## Not run: DatasetMigration.create(dataset_id=<ID>, upload_id=<ID>) ## End(Not run)
Deletes specific dataset migration on SolveBio.
DatasetMigration.delete(id, env = solvebio:::.solveEnv)DatasetMigration.delete(id, env = solvebio:::.solveEnv)
id |
String The ID of a SolveBio dataset migration. |
env |
(optional) Custom client environment. |
## Not run: DatasetMigration.delete(<ID>) ## End(Not run)## Not run: DatasetMigration.delete(<ID>) ## End(Not run)
Retrieves the metadata about a specific dataset migration on SolveBio.
DatasetMigration.retrieve(id, env = solvebio:::.solveEnv)DatasetMigration.retrieve(id, env = solvebio:::.solveEnv)
id |
String The ID of a SolveBio dataset migration. |
env |
(optional) Custom client environment. |
## Not run: DatasetMigration.retrieve(<ID>) ## End(Not run)## Not run: DatasetMigration.retrieve(<ID>) ## End(Not run)
Retrieves the metadata about all dataset templates on SolveBio.
DatasetTemplate.all(env = solvebio:::.solveEnv, ...)DatasetTemplate.all(env = solvebio:::.solveEnv, ...)
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters (e.g. page). |
## Not run: DatasetTemplate.all() ## End(Not run)## Not run: DatasetTemplate.all() ## End(Not run)
Create a SolveBio dataset template.
DatasetTemplate.create(env = solvebio:::.solveEnv, ...)DatasetTemplate.create(env = solvebio:::.solveEnv, ...)
env |
(optional) Custom client environment. |
... |
(optional) Dataset template attributes. |
## Not run: DatasetTemplate.create(name="My Dataset Template") ## End(Not run)## Not run: DatasetTemplate.create(name="My Dataset Template") ## End(Not run)
Deletes a specific dataset template on SolveBio.
DatasetTemplate.delete(id, env = solvebio:::.solveEnv)DatasetTemplate.delete(id, env = solvebio:::.solveEnv)
id |
String The ID or full name of a SolveBio dataset template. |
env |
(optional) Custom client environment. |
## Not run: DatasetTemplate.delete(<ID>) ## End(Not run)## Not run: DatasetTemplate.delete(<ID>) ## End(Not run)
Retrieves the metadata about a specific dataset template on SolveBio.
DatasetTemplate.retrieve(id, env = solvebio:::.solveEnv)DatasetTemplate.retrieve(id, env = solvebio:::.solveEnv)
id |
String The ID of a SolveBio dataset template. |
env |
(optional) Custom client environment. |
## Not run: DatasetTemplate.retrieve(<ID>) ## End(Not run)## Not run: DatasetTemplate.retrieve(<ID>) ## End(Not run)
Updates the attributes of an existing dataset template.
DatasetTemplate.update(id, env = solvebio:::.solveEnv, ...)DatasetTemplate.update(id, env = solvebio:::.solveEnv, ...)
id |
The ID of the dataset template to update. |
env |
(optional) Custom client environment. |
... |
Dataset template attributes to change. |
## Not run: DatasetTemplate.update( id="1234", name="New Template Name", ) ## End(Not run)## Not run: DatasetTemplate.update( id="1234", name="New Template Name", ) ## End(Not run)
Evaluate a SolveBio expression.
Expression.evaluate( expression, data_type = "string", is_list = FALSE, data = NULL, raw = FALSE, env = solvebio:::.solveEnv )Expression.evaluate( expression, data_type = "string", is_list = FALSE, data = NULL, raw = FALSE, env = solvebio:::.solveEnv )
expression |
The SolveBio expression string. |
data_type |
The data type to cast the expression result (default: string). |
is_list |
Set to TRUE if the result is expected to be a list (default: FALSE). |
data |
Variables used in the expression (default: NULL). |
raw |
Set to TRUE to return the raw response (default: FALSE). |
env |
(optional) Custom client environment. |
## Not run: Expression.evaluate("1 + 1", data_type="integer", is_list=FALSE) ## End(Not run)## Not run: Expression.evaluate("1 + 1", data_type="integer", is_list=FALSE) ## End(Not run)
Performs a Global Search based on provided filters, entities, queries, and returns an R data frame containing the facets results from API response.
GlobalSearch.facets(facets, env = solvebio:::.solveEnv, ...)GlobalSearch.facets(facets, env = solvebio:::.solveEnv, ...)
facets |
Facets list. |
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters (e.g. filters, entities, query). |
## Not run: GlobalSearch.facets(facets="study") ## End(Not run)## Not run: GlobalSearch.facets(facets="study") ## End(Not run)
Performs a single Global Search API request with the provided filters, queries and entities. A single request will only retrieve one page of results (based on the 'limit' parameter). Use 'GlobalSearch.search()' to retrieve all pages of results. Returns the full API response (containing attributes: results, vaults, subjects, subjects_count, total)
GlobalSearch.request( query = NULL, filters, entities, env = solvebio:::.solveEnv, ... )GlobalSearch.request( query = NULL, filters, entities, env = solvebio:::.solveEnv, ... )
query |
(optional) Advanced search query. |
filters |
(optional) Low-level filter specification. |
entities |
(optional) Low-level entity specification. |
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters (e.g. limit, offset). |
## Not run: # No filters are applied GlobalSearch.request() # Global Beacon search GlobalSearch.request(entities = '[["gene","BRCA2"]]') # Type filter (only vaults) GlobalSearch.request(filters = '[{"and":[["type__in",["vault"]]]}]') # Advanced search GlobalSearch.request(query = "fuji") # Multiple filters and entities GlobalSearch.request( entities = '[["gene","BRCA2"]]', filters = '[{ "and": [ {"and": [ ["created_at__range",["2021-11-28","2021-12-28"]]]}, ["type__in",["dataset"]] ] }]' ) ## End(Not run)## Not run: # No filters are applied GlobalSearch.request() # Global Beacon search GlobalSearch.request(entities = '[["gene","BRCA2"]]') # Type filter (only vaults) GlobalSearch.request(filters = '[{"and":[["type__in",["vault"]]]}]') # Advanced search GlobalSearch.request(query = "fuji") # Multiple filters and entities GlobalSearch.request( entities = '[["gene","BRCA2"]]', filters = '[{ "and": [ {"and": [ ["created_at__range",["2021-11-28","2021-12-28"]]]}, ["type__in",["dataset"]] ] }]' ) ## End(Not run)
Performs a Global Search based on provided filters, entities, queries, and returns an R data frame containing results from API response. Returns a single page of results otherwise (default).
GlobalSearch.search(paginate = FALSE, env = solvebio:::.solveEnv, ...)GlobalSearch.search(paginate = FALSE, env = solvebio:::.solveEnv, ...)
paginate |
When set to TRUE, retrieves all records (memory permitting). |
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters (e.g. filters, entities, query, limit, offset). |
## Not run: # No filters applied GlobalSearch.search() #Global Beacon search GlobalSearch.search(entities = '[["gene","BRCA2"]]') GlobalSearch.search(filters = '[{"and":[["type__in",["vault"]]]}]') # Advanced search GlobalSearch.search(query = "fuji") ## End(Not run)## Not run: # No filters applied GlobalSearch.search() #Global Beacon search GlobalSearch.search(entities = '[["gene","BRCA2"]]') GlobalSearch.search(filters = '[{"and":[["type__in",["vault"]]]}]') # Advanced search GlobalSearch.search(query = "fuji") ## End(Not run)
Performs a Global Search based on provided filters, entities, queries, and returns an R data frame containing subjects from API response.
GlobalSearch.subjects(env = solvebio:::.solveEnv, ...)GlobalSearch.subjects(env = solvebio:::.solveEnv, ...)
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters (e.g. filters, entities, query, limit, offset). |
## Not run: GlobalSearch.subjects(entities = '[["gene","BRCA2"]]') ## End(Not run)## Not run: GlobalSearch.subjects(entities = '[["gene","BRCA2"]]') ## End(Not run)
Performs a Global Search based on provided filters, entities, queries, and returns the total number of subjects from API response.
GlobalSearch.subjects_count(env = solvebio:::.solveEnv, ...)GlobalSearch.subjects_count(env = solvebio:::.solveEnv, ...)
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters (e.g. filters, entities, query, limit, offset). |
## Not run: GlobalSearch.subjects_count(entities = '[["gene","BRCA2"]]') ## End(Not run)## Not run: GlobalSearch.subjects_count(entities = '[["gene","BRCA2"]]') ## End(Not run)
Store and verify your SolveBio credentials.
login(api_key, api_host, env = solvebio:::.solveEnv)login(api_key, api_host, env = solvebio:::.solveEnv)
api_key |
Your SolveBio API key |
api_host |
SolveBio API host (default: https://api.solvebio.com) |
env |
(optional) The R environment used to store API credentials. |
## Not run: login() ## End(Not run)## Not run: login() ## End(Not run)
Retrieves the metadata about all objects on SolveBio accessible to the current user.
Object.all(env = solvebio:::.solveEnv, ...)Object.all(env = solvebio:::.solveEnv, ...)
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters. |
## Not run: Object.all() ## End(Not run)## Not run: Object.all() ## End(Not run)
Create a SolveBio object.
Object.create( vault_id, parent_object_id, object_type, filename, env = solvebio:::.solveEnv, ... )Object.create( vault_id, parent_object_id, object_type, filename, env = solvebio:::.solveEnv, ... )
vault_id |
The target vault ID. |
parent_object_id |
The ID of the parent object (folder) or NULL for the vault root. |
object_type |
The type of object (i.e. "folder"). |
filename |
The filename (i.e. the name) of the object. |
env |
(optional) Custom client environment. |
... |
(optional) Additional object attributes. |
## Not run: Object.create( vault_id="1234567890", parent_object_id=NULL, object_type="folder", filename="My Folder" ) ## End(Not run)## Not run: Object.create( vault_id="1234567890", parent_object_id=NULL, object_type="folder", filename="My Folder" ) ## End(Not run)
Returns one page of documents from a SolveBio file (object) and processes the response.
Object.data(id, filters, col.names = NULL, env = solvebio:::.solveEnv, ...)Object.data(id, filters, col.names = NULL, env = solvebio:::.solveEnv, ...)
id |
The ID of a SolveBio file (vault object). |
filters |
(optional) Query filters. |
col.names |
(optional) Force data frame column name ordering. |
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters (e.g. limit, offset). |
## Not run: Object.data("1234567890") ## End(Not run)## Not run: Object.data("1234567890") ## End(Not run)
Delete a specific object from SolveBio.
Object.delete(id, env = solvebio:::.solveEnv)Object.delete(id, env = solvebio:::.solveEnv)
id |
The ID of the object. |
env |
(optional) Custom client environment. |
## Not run: Object.delete("1234567890") ## End(Not run)## Not run: Object.delete("1234567890") ## End(Not run)
Disables Global Beacon for the specified dataset.
Object.disable_global_beacon(id, env = solvebio:::.solveEnv)Object.disable_global_beacon(id, env = solvebio:::.solveEnv)
id |
The ID of a SolveBio dataset. |
env |
(optional) Custom client environment. |
## Not run: Object.disable_global_beacon("1234567890") ## End(Not run)## Not run: Object.disable_global_beacon("1234567890") ## End(Not run)
Enables Global Beacon for the specified dataset.
Object.enable_global_beacon(id, env = solvebio:::.solveEnv)Object.enable_global_beacon(id, env = solvebio:::.solveEnv)
id |
The ID of a SolveBio dataset. |
env |
(optional) Custom client environment. |
## Not run: Object.enable_global_beacon("1234567890") ## End(Not run)## Not run: Object.enable_global_beacon("1234567890") ## End(Not run)
Retrieves the list of fields for a file (JSON, CSV, or TSV).
Object.fields(id, env = solvebio:::.solveEnv, ...)Object.fields(id, env = solvebio:::.solveEnv, ...)
id |
The ID of a SolveBio file (vault object). |
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters (e.g. limit, offset). |
## Not run: Object.fields("1234567890") ## End(Not run)## Not run: Object.fields("1234567890") ## End(Not run)
A helper function to get an object on SolveBio by its full path.
Object.get_by_full_path(full_path, env = solvebio:::.solveEnv, ...)Object.get_by_full_path(full_path, env = solvebio:::.solveEnv, ...)
full_path |
The full path to the object. |
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters. |
## Not run: Object.get_by_full_path("solvebio:public:/ClinVar") ## End(Not run)## Not run: Object.get_by_full_path("solvebio:public:/ClinVar") ## End(Not run)
A helper function to get an object on SolveBio by its path. Used as a pass-through function from some Vault methods.
Object.get_by_path(path, env = solvebio:::.solveEnv, ...)Object.get_by_path(path, env = solvebio:::.solveEnv, ...)
path |
The path to the object, relative to a vault. |
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters. |
## Not run: Object.get_by_path("/ClinVar") ## End(Not run)## Not run: Object.get_by_path("/ClinVar") ## End(Not run)
Helper method to get the download URL for a file object.
Object.get_download_url(id, env = solvebio:::.solveEnv)Object.get_download_url(id, env = solvebio:::.solveEnv)
id |
The ID of the object. |
env |
(optional) Custom client environment. |
## Not run: Object.get_download_url("1234567890") ## End(Not run)## Not run: Object.get_download_url("1234567890") ## End(Not run)
Retrieves the global beacon status for the specified dataset.
Object.get_global_beacon_status( id, raise_on_disabled = FALSE, env = solvebio:::.solveEnv )Object.get_global_beacon_status( id, raise_on_disabled = FALSE, env = solvebio:::.solveEnv )
id |
The ID of a SolveBio dataset. |
raise_on_disabled |
Whether to raise an exception if Global Beacon is disabled or to return NULL. |
env |
(optional) Custom client environment. |
## Not run: Object.get_global_beacon_status("1234567890") Object.get_global_beacon_status("1234567890", raise_on_disabled=TRUE) ## End(Not run)## Not run: Object.get_global_beacon_status("1234567890") Object.get_global_beacon_status("1234567890", raise_on_disabled=TRUE) ## End(Not run)
Upload a local file to a vault on SolveBio only if it does not yet exist (by name, at the provided path). The vault path provided is the parent directory for uploaded file. Accepts the same arguments as 'Object.upload_file'.
Object.get_or_upload_file( local_path, vault_id, vault_path, filename, env = solvebio:::.solveEnv )Object.get_or_upload_file( local_path, vault_id, vault_path, filename, env = solvebio:::.solveEnv )
local_path |
The path to the local file |
vault_id |
The SolveBio vault ID |
vault_path |
The remote path in the vault |
filename |
(optional) The filename for the uploaded file in the vault (default: the basename of the local_path) |
env |
(optional) Custom client environment. |
## Not run: Object.get_or_upload_file("my_file.json.gz", vault$id, "/parent/directory/") ## End(Not run)## Not run: Object.get_or_upload_file("my_file.json.gz", vault$id, "/parent/directory/") ## End(Not run)
Queries a SolveBio file (vault object) and returns an R data frame containing all records. Returns a single page of results otherwise (default).
Object.query(id, paginate = FALSE, env = solvebio:::.solveEnv, ...)Object.query(id, paginate = FALSE, env = solvebio:::.solveEnv, ...)
id |
The ID of a SolveBio file (vault object). |
paginate |
When set to TRUE, retrieves all records (memory permitting). |
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters (e.g. filters, limit, offset). |
## Not run: Object.query("12345678790", paginate=TRUE) ## End(Not run)## Not run: Object.query("12345678790", paginate=TRUE) ## End(Not run)
Retrieves the metadata about a specific object on SolveBio.
Object.retrieve(id, env = solvebio:::.solveEnv)Object.retrieve(id, env = solvebio:::.solveEnv)
id |
The ID of the object. |
env |
(optional) Custom client environment. |
## Not run: Object.retrieve("1234567890") ## End(Not run)## Not run: Object.retrieve("1234567890") ## End(Not run)
Updates the attributes of an existing vault object.
Object.update(id, env = solvebio:::.solveEnv, ...)Object.update(id, env = solvebio:::.solveEnv, ...)
id |
The ID of the vault to update. |
env |
(optional) Custom client environment. |
... |
Object attributes to change. |
## Not run: Object.update( id="1234", filename="New Name", ) ## End(Not run)## Not run: Object.update( id="1234", filename="New Name", ) ## End(Not run)
Upload a local file to a vault on SolveBio. The vault path provided is the parent directory for uploaded file.
Object.upload_file( local_path, vault_id, vault_path, filename, env = solvebio:::.solveEnv )Object.upload_file( local_path, vault_id, vault_path, filename, env = solvebio:::.solveEnv )
local_path |
The path to the local file |
vault_id |
The SolveBio vault ID |
vault_path |
The remote path in the vault |
filename |
(optional) The filename for the uploaded file in the vault (default: the basename of the local_path) |
env |
(optional) Custom client environment. |
## Not run: Object.upload_file("my_file.json.gz", vault$id, "/parent/directory/") ## End(Not run)## Not run: Object.upload_file("my_file.json.gz", vault$id, "/parent/directory/") ## End(Not run)
Wraps an existing Shiny server in an OAuth2 flow.
protectedServer( server, client_id, client_secret = NULL, base_url = "https://my.solvebio.com" )protectedServer( server, client_id, client_secret = NULL, base_url = "https://my.solvebio.com" )
server |
Your original Shiny server function. |
client_id |
Your application's client ID. |
client_secret |
(optional) Your application's client secret. |
base_url |
(optional) Override the default login host (default: https://my.solvebio.com). |
## Not run: protectedServer( server=server, client_id="abcd1234" ) ## End(Not run)## Not run: protectedServer( server=server, client_id="abcd1234" ) ## End(Not run)
Returns ShinyJS-compatible JS code to support cookie-based token storage.
protectedServerJS()protectedServerJS()
## Not run: jscookie_src <- "https://cdnjs.cloudflare.com/ajax/libs/js-cookie/2.2.0/js.cookie.js" ui <- fluidPage( shiny::tags$head( shiny::tags$script(src = jscookie_src) ), useShinyjs(), extendShinyjs(text = solvebio::protectedServerJS(), functions = c("enableCookieAuth", "getCookie", "setCookie", "rmCookie")) ) ## End(Not run)## Not run: jscookie_src <- "https://cdnjs.cloudflare.com/ajax/libs/js-cookie/2.2.0/js.cookie.js" ui <- fluidPage( shiny::tags$head( shiny::tags$script(src = jscookie_src) ), useShinyjs(), extendShinyjs(text = solvebio::protectedServerJS(), functions = c("enableCookieAuth", "getCookie", "setCookie", "rmCookie")) ) ## End(Not run)
Retrieves the all saved queries on SolveBio.
SavedQuery.all(env = solvebio:::.solveEnv, ...)SavedQuery.all(env = solvebio:::.solveEnv, ...)
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters (e.g. page). |
## Not run: SavedQuery.all() ## End(Not run)## Not run: SavedQuery.all() ## End(Not run)
Create a SolveBio saved query.
SavedQuery.create(env = solvebio:::.solveEnv, ...)SavedQuery.create(env = solvebio:::.solveEnv, ...)
env |
(optional) Custom client environment. |
... |
(optional) Saved query attributes. |
## Not run: SavedQuery.create(name="My Dataset Template") ## End(Not run)## Not run: SavedQuery.create(name="My Dataset Template") ## End(Not run)
Deletes a specific saved query on SolveBio.
SavedQuery.delete(id, env = solvebio:::.solveEnv)SavedQuery.delete(id, env = solvebio:::.solveEnv)
id |
String The ID of the SolveBio saved query. |
env |
(optional) Custom client environment. |
## Not run: SavedQuery.delete(<ID>) ## End(Not run)## Not run: SavedQuery.delete(<ID>) ## End(Not run)
Retrieves a specific saved query on SolveBio by ID.
SavedQuery.retrieve(id, env = solvebio:::.solveEnv)SavedQuery.retrieve(id, env = solvebio:::.solveEnv)
id |
String The ID of a SolveBio saved query. |
env |
(optional) Custom client environment. |
## Not run: SavedQuery.retrieve(<ID>) ## End(Not run)## Not run: SavedQuery.retrieve(<ID>) ## End(Not run)
Updates the attributes of an existing saved query.
SavedQuery.update(id, env = solvebio:::.solveEnv, ...)SavedQuery.update(id, env = solvebio:::.solveEnv, ...)
id |
The ID of the saved query to update. |
env |
(optional) Custom client environment. |
... |
Saved query attributes to change. |
## Not run: SavedQuery.update( id="1234", name="New query Name", ) ## End(Not run)## Not run: SavedQuery.update( id="1234", name="New query Name", ) ## End(Not run)
Retrieves the metadata about all tasks on SolveBio accessible to the current user.
Task.all(env = solvebio:::.solveEnv, ...)Task.all(env = solvebio:::.solveEnv, ...)
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters. |
## Not run: Task.all() ## End(Not run)## Not run: Task.all() ## End(Not run)
A helper function to follow a specific task until it gets completed.
Task.follow(id, env = solvebio:::.solveEnv, interval = 2)Task.follow(id, env = solvebio:::.solveEnv, interval = 2)
id |
String The ID of a task. |
env |
(optional) Custom client environment. |
interval |
2. Delay in seconds between each completion status query |
the task object
## Not run: Task.follow("1234567890") ## End(Not run)## Not run: Task.follow("1234567890") ## End(Not run)
Retrieves the metadata about a specific task on SolveBio.
Task.retrieve(id, env = solvebio:::.solveEnv)Task.retrieve(id, env = solvebio:::.solveEnv)
id |
The ID of a task. |
env |
(optional) Custom client environment. |
## Not run: Task.retrieve("1234567890") ## End(Not run)## Not run: Task.retrieve("1234567890") ## End(Not run)
Retrieves information about the current user.
User.retrieve(env = solvebio:::.solveEnv)User.retrieve(env = solvebio:::.solveEnv)
env |
(optional) Custom client environment. |
## Not run: User.retrieve() ## End(Not run)## Not run: User.retrieve() ## End(Not run)
Retrieves the metadata about all accessible vaults.
Vault.all(..., env = solvebio:::.solveEnv)Vault.all(..., env = solvebio:::.solveEnv)
... |
(optional) Additional query parameters (e.g. limit, offset). |
env |
(optional) Custom client environment. |
## Not run: Vault.all() ## End(Not run)## Not run: Vault.all() ## End(Not run)
Create a new SolveBio vault.
Vault.create(name, env = solvebio:::.solveEnv, ...)Vault.create(name, env = solvebio:::.solveEnv, ...)
name |
The unique name of the vault. |
env |
(optional) Custom client environment. |
... |
(optional) Additional vault attributes. |
## Not run: Vault.create(name="my-domain:MyVault") ## End(Not run)## Not run: Vault.create(name="my-domain:MyVault") ## End(Not run)
Create a new dataset in a vault.
Vault.create_dataset(id, path, name, env = solvebio:::.solveEnv, ...)Vault.create_dataset(id, path, name, env = solvebio:::.solveEnv, ...)
id |
The ID of the vault. |
path |
The path to the dataset, within the vault. |
name |
The name (filename) for the dataset. |
env |
(optional) Custom client environment. |
... |
(optional) Additional dataset creation parameters. |
## Not run: vault = Vault.get_personal_vault() Vault.create_dataset(vault$id, path="/", name="My Dataset") ## End(Not run)## Not run: vault = Vault.get_personal_vault() Vault.create_dataset(vault$id, path="/", name="My Dataset") ## End(Not run)
Create a new folder in a vault.
Vault.create_folder( id, path, recursive = FALSE, env = solvebio:::.solveEnv, ... )Vault.create_folder( id, path, recursive = FALSE, env = solvebio:::.solveEnv, ... )
id |
The ID of the vault. |
path |
The path to the folder, within the vault. |
recursive |
Create all parent directories that do not yet exist (default: FALSE). |
env |
(optional) Custom client environment. |
... |
(optional) Additional folder creation parameters. |
## Not run: vault = Vault.get_personal_vault() Vault.create_folder(vault$id, "/My Folder") ## End(Not run)## Not run: vault = Vault.get_personal_vault() Vault.create_folder(vault$id, "/My Folder") ## End(Not run)
Retrieves all datasets in a specific vault.
Vault.datasets(id, env = solvebio:::.solveEnv, ...)Vault.datasets(id, env = solvebio:::.solveEnv, ...)
id |
The ID of the vault. |
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters (e.g. limit, offset). |
## Not run: vault = Vault.get_personal_vault() Vault.datasets(vault$id) ## End(Not run)## Not run: vault = Vault.get_personal_vault() Vault.datasets(vault$id) ## End(Not run)
Delete a specific vault from SolveBio. This operation cannot be undone.
Vault.delete(id, env = solvebio:::.solveEnv)Vault.delete(id, env = solvebio:::.solveEnv)
id |
String The ID of a SolveBio vault. |
env |
(optional) Custom client environment. |
## Not run: Vault.delete("1") ## End(Not run)## Not run: Vault.delete("1") ## End(Not run)
Retrieves all files in a specific vault.
Vault.files(id, env = solvebio:::.solveEnv, ...)Vault.files(id, env = solvebio:::.solveEnv, ...)
id |
The ID of the vault. |
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters (e.g. limit, offset). |
## Not run: vault = Vault.get_personal_vault() Vault.files(vault$id) ## End(Not run)## Not run: vault = Vault.get_personal_vault() Vault.files(vault$id) ## End(Not run)
Retrieves all folders in a specific vault.
Vault.folders(id, env = solvebio:::.solveEnv, ...)Vault.folders(id, env = solvebio:::.solveEnv, ...)
id |
The ID of the vault. |
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters (e.g. limit, offset). |
## Not run: vault = Vault.get_personal_vault() Vault.folders(vault$id) ## End(Not run)## Not run: vault = Vault.get_personal_vault() Vault.folders(vault$id) ## End(Not run)
Retrieves a specific vault by its full path (domain:vault).
Vault.get_by_full_path(full_path, verbose = TRUE, env = solvebio:::.solveEnv)Vault.get_by_full_path(full_path, verbose = TRUE, env = solvebio:::.solveEnv)
full_path |
The full path of a SolveBio vault. |
verbose |
Print warning/error messages (default: TRUE). |
env |
(optional) Custom client environment. |
## Not run: Vault.get_by_full_path("SolveBio:Public") ## End(Not run)## Not run: Vault.get_by_full_path("SolveBio:Public") ## End(Not run)
Retrieves or creates a specific vault by its full path (domain:vault).
Vault.get_or_create_by_full_path(full_path, env = solvebio:::.solveEnv, ...)Vault.get_or_create_by_full_path(full_path, env = solvebio:::.solveEnv, ...)
full_path |
The full path of a SolveBio vault. |
env |
(optional) Custom client environment. |
... |
(optional) Additional parameters. |
## Not run: Vault.get_or_create_by_full_path("My New Vault") ## End(Not run)## Not run: Vault.get_or_create_by_full_path("My New Vault") ## End(Not run)
Retrieves the current users"s personal, private vault.
Vault.get_personal_vault(env = solvebio:::.solveEnv)Vault.get_personal_vault(env = solvebio:::.solveEnv)
env |
(optional) Custom client environment. |
## Not run: Vault.get_personal_vault() ## End(Not run)## Not run: Vault.get_personal_vault() ## End(Not run)
Retrieves all objects in a specific vault.
Vault.objects(id, env = solvebio:::.solveEnv, ...)Vault.objects(id, env = solvebio:::.solveEnv, ...)
id |
The ID of the vault. |
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters (e.g. limit, offset). |
## Not run: vault = Vault.get_personal_vault() Vault.objects(vault$id) ## End(Not run)## Not run: vault = Vault.get_personal_vault() Vault.objects(vault$id) ## End(Not run)
Retrieves the metadata about a specific SolveBio vault.
Vault.retrieve(id, env = solvebio:::.solveEnv)Vault.retrieve(id, env = solvebio:::.solveEnv)
id |
String The ID of a SolveBio vault |
env |
(optional) Custom client environment. |
## Not run: Vault.retrieve("1234567890") ## End(Not run)## Not run: Vault.retrieve("1234567890") ## End(Not run)
Search for objects in a specific vault.
Vault.search(id, query, env = solvebio:::.solveEnv, ...)Vault.search(id, query, env = solvebio:::.solveEnv, ...)
id |
The ID of the vault. |
query |
The search query. |
env |
(optional) Custom client environment. |
... |
(optional) Additional query parameters (e.g. limit, offset). |
## Not run: vault = Vault.get_personal_vault() Vault.search('test') ## End(Not run)## Not run: vault = Vault.get_personal_vault() Vault.search('test') ## End(Not run)
Updates the attributes of an existing vault.
Vault.update(id, env = solvebio:::.solveEnv, ...)Vault.update(id, env = solvebio:::.solveEnv, ...)
id |
The ID of the vault to update. |
env |
(optional) Custom client environment. |
... |
Vault attributes to change. |
## Not run: Vault.update( id="1234", name="New Vault Name", ) ## End(Not run)## Not run: Vault.update( id="1234", name="New Vault Name", ) ## End(Not run)